<?php

namespace Drupal\peertube;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Defines PeertubeService class.
 */
class PeertubeService extends ControllerBase {

  /**
   * The PeerTube configuration.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $peerTubeConfig;

  /**
   * Constructs a PeertubeService object
   *
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler service.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->peerTubeConfig = $config_factory->get('peertube.settings');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * Add PeerTube providers to the list.
   *
   * @param array $data
   *   The default providers list.
   *
   * @return array
   *   The comple providers list with PeerTube ones.
   */
  public function getPeertubeProviders() {
    $peertube_providers = $this->peerTubeConfig->get('peertube_instances');
    $peertube_providers_list = explode("\r\n", $peertube_providers);

    $peertube_data = [
      'provider_name' => 'PeerTube',
      'provider_url' => 'https://joinpeertube.org',
      'endpoints' => [],
    ];

    foreach($peertube_providers_list as $peertube_provider) {
      $peertube_data['endpoints'][] = $this->getPeertubeEndpoint($peertube_provider);
    }
    return $peertube_data;
  }

  /**
   * Function to get the peertube provider endpoint.
   *
   * @param string $provider_url
   *   The provider URL.
   *
   * @return array
   *   The provider endpoint representation.
   */
  public function getPeertubeEndpoint($provider_url) {
    return [
      'schemes' => [
        $provider_url . '/videos/watch/*',
      ],
      'url' => $provider_url . '/services/oembed',
      'discovery' => TRUE,
    ];
  }

}
